@@ -18,10 +18,7 @@ import time
 import logging
 from collections import defaultdict
 
-from six import iteritems
-from six.moves import xrange
-
-from scipy import zeros
+from numpy import zeros
 from scipy.sparse import lil_matrix
 
 from nazca.utils.dataio import parsefile
@@ -117,8 +114,8 @@ class BaseAligner(object):
 
     def _get_match(self, refset, targetset, ref_indexes=None, target_indexes=None):
         # Build items
-        ref_indexes = ref_indexes or xrange(len(refset))
-        target_indexes = target_indexes or xrange(len(targetset))
+        ref_indexes = ref_indexes or range(len(refset))
+        target_indexes = target_indexes or range(len(targetset))
         # Apply alignments
         mat = self.compute_distance_matrix(
             refset, targetset, ref_indexes=ref_indexes, target_indexes=target_indexes
@@ -126,7 +123,7 @@ class BaseAligner(object):
         matched = self.threshold_matched(mat)
         # Reapply matched to global indexes
         new_matched = {}
-        for k, values in iteritems(matched):
+        for k, values in matched.items():
             new_matched[ref_indexes[k]] = [(target_indexes[i], d) for i, d in values]
         return mat, new_matched
 
@@ -152,7 +149,7 @@ class BaseAligner(object):
             target_index = [r[0] for r in targetblock]
             self.nb_comparisons += len(ref_index) * len(target_index)
             _, matched = self._get_match(refset, targetset, ref_index, target_index)
-            for k, values in iteritems(matched):
+            for k, values in matched.items():
                 subdict = global_matched.setdefault(k, set())
                 for v, d in values:
                     subdict.add((v, d))
@@ -169,9 +166,11 @@ class BaseAligner(object):
         if not refset or not targetset:
             return
         global_mat, global_matched = self.align(refset, targetset, get_matrix=use_distance)
-        for pair in iter_aligned_pairs(refset, targetset, global_mat, global_matched, unique):
+        for refitem, targetitem, distance in iter_aligned_pairs(
+            refset, targetset, global_mat, global_matched, unique
+        ):
             self.pairs_found += 1
-            yield pair
+            yield refitem, targetitem, distance
         self.log_infos()
 
     def align_from_files(
@@ -236,8 +235,7 @@ class BaseAligner(object):
         if not refset or not targetset:
             return
         global_mat, global_matched = self.align(refset, targetset, get_matrix=False)
-        for pair in iter_aligned_pairs(refset, targetset, global_mat, global_matched, unique):
-            yield pair
+        yield from iter_aligned_pairs(refset, targetset, global_mat, global_matched, unique)
 
     def log_infos(self):
         """ Display some info on the aligner process
@@ -310,11 +308,14 @@ class PipelineAligner(object):
             # Perform alignment
             _refset = [refset[i] for i in ref_index]
             _targetset = [targetset[i] for i in target_index]
-            for pair in aligner.get_aligned_pairs(_refset, _targetset, unique):
+            for refitem, targetitem, distance in aligner.get_aligned_pairs(
+                _refset, _targetset, unique
+            ):
                 self.pairs_found += 1
-                pair = ((pair[0][0], ref_index[pair[0][1]]), (pair[1][0], target_index[pair[1][1]]))
-                yield pair
-                seen_refset.add(pair[0][1])
+                reindexed_refitem = (refitem[0], ref_index[refitem[1]])
+                reindexed_targetitem = (targetitem[0], target_index[targetitem[1]])
+                yield reindexed_refitem, reindexed_targetitem, distance
+                seen_refset.add(ref_index[refitem[1]])
             # Store stats
             self.nb_blocks += aligner.nb_blocks
             self.nb_comparisons += aligner.nb_comparisons
