@@ -397,8 +397,7 @@ class ValidXHTMLPrettyPrint(HTMLPrettyPrint):
             html = html.encode("utf-8")
         try:
             etree.fromstring(
-                self.XHTML_DOC_TEMPLATE % html,
-                parser=etree.XMLParser(no_network=False, dtd_validation=True),
+                self.XHTML_DOC_TEMPLATE % html, parser=etree.XMLParser(dtd_validation=True),
             )
         except etree.XMLSyntaxError:
             return False
