@@ -19,22 +19,36 @@ import difflib
 from functools import partial
 from math import cos, sqrt, pi  # Needed for geographical distance
 
-from six.moves import xrange
-
 try:
     from dateutil import parser as dateparser
 
     DATEUTIL_ENABLED = True
 except ImportError:
     DATEUTIL_ENABLED = False
-from scipy import array, empty
+from numpy import array, empty
 
 from nazca.utils.normalize import tokenize
 
+MAX_AUTOMATIC_CONFIDENCE = 0.9
+
 
 ###############################################################################
 # UTILITY FUNCTIONS ###########################################################
 ###############################################################################
+def distance_to_confidence(
+    distance, max_confidence=MAX_AUTOMATIC_CONFIDENCE, max_distance=1,
+):
+    """ Return a confidence between 0 and max_confidence based on the result of a Nazca
+    processing
+        :params distance: float (between 0 (exact match) and `max_distance`)
+        :params max_confidence: the maximum confidence that can be returned.
+        :params max_distance: the maximal distance that be used as input
+            (usually 1, when a normalisation is used)
+        :return: the confidence (float)
+    """
+    return min(max_confidence, round((max_distance - distance) / max_distance, 2))
+
+
 def cdist(
     distance_callback,
     refset,
@@ -57,8 +71,8 @@ def cdist(
     A distance matrix, of shape (len(refset), len(targetset))
     with the distance of each element in it.
     """
-    ref_indexes = ref_indexes or xrange(len(refset))
-    target_indexes = target_indexes or xrange(len(targetset))
+    ref_indexes = ref_indexes or range(len(refset))
+    target_indexes = target_indexes or range(len(targetset))
     distmatrix = empty((len(ref_indexes), len(target_indexes)), dtype="float32")
     for i, iref in enumerate(ref_indexes):
         for j, jref in enumerate(target_indexes):
@@ -104,11 +118,11 @@ def _handlespaces(stra, strb, distance, tokenizer=None, **kwargs):
         mint.extend(["" for i in range(len(maxt) - len(mint))])
 
     listmatrix = []
-    for i in xrange(len(toka)):
-        listmatrix.append([distance(toka[i], tokb[j], **kwargs) for j in xrange(len(tokb))])
+    for i in range(len(toka)):
+        listmatrix.append([distance(toka[i], tokb[j], **kwargs) for j in range(len(tokb))])
     m = array(listmatrix)
-    minlist = [m[i, :].min() for i in xrange(m.shape[0])]
-    minlist.extend([m[:, i].min() for i in xrange(m.shape[1])])
+    minlist = [m[i, :].min() for i in range(m.shape[0])]
+    minlist.extend([m[:, i].min() for i in range(m.shape[1])])
     return max(minlist)
 
 
@@ -152,9 +166,9 @@ def levenshtein(stra, strb, tokenizer=None):
     lenb = len(strb)
     onerowago = None
     thisrow = list(range(1, lenb + 1)) + [0]
-    for x in xrange(len(stra)):
+    for x in range(len(stra)):
         onerowago, thisrow = thisrow, [0] * lenb + [x + 1]
-        for y in xrange(lenb):
+        for y in range(lenb):
             delcost = onerowago[y] + 1
             addcost = thisrow[y - 1] + 1
             subcost = onerowago[y - 1] + (stra[x] != strb[y])
@@ -230,7 +244,7 @@ def soundexcode(word, language="french"):
     # where from consecutive consonnants, only the first is kept,
     # and from two identical consonnants separated by a W or a H, only the first
     # is kept too.
-    for i in xrange(1, len(word)):
+    for i in range(1, len(word)):
         if word[i] in vowels:
             continue
         if word[i - 1] not in vowels and consonnantscode[word[i]] == consonnantscode.get(
@@ -313,38 +327,38 @@ if DATEUTIL_ENABLED:
         """
 
         HMS = [
-            (u"h", u"heure", u"heures"),
-            (u"m", u"minute", u"minutes"),
-            (u"s", u"seconde", u"seconde"),
+            ("h", "heure", "heures"),
+            ("m", "minute", "minutes"),
+            ("s", "seconde", "seconde"),
         ]
-        JUMP = [u" ", u".", u",", u";", u"-", u"/", u"'", u"a", u"le", u"et", u"er"]
+        JUMP = [" ", ".", ",", ";", "-", "/", "'", "a", "le", "et", "er"]
         MONTHS = [
-            (u"Jan", u"Janvier"),
-            (u"Fev", u"Fevrier"),
-            (u"Mar", u"Mars"),
-            (u"Avr", u"Avril"),
-            (u"Mai", u"Mai"),
-            (u"Jun", u"Juin"),
-            (u"Jui", u"Juillet"),
-            (u"Aou", u"Aout"),
-            (u"Sep", u"Septembre"),
-            (u"Oct", u"Octobre"),
-            (u"Nov", u"Novembre"),
-            (u"Dec", u"Decembre"),
+            ("Jan", "Janvier"),
+            ("Fev", "Fevrier"),
+            ("Mar", "Mars"),
+            ("Avr", "Avril"),
+            ("Mai", "Mai"),
+            ("Jun", "Juin"),
+            ("Jui", "Juillet"),
+            ("Aou", "Aout"),
+            ("Sep", "Septembre"),
+            ("Oct", "Octobre"),
+            ("Nov", "Novembre"),
+            ("Dec", "Decembre"),
         ]
-        PERTAIN = [u"de"]
+        PERTAIN = ["de"]
         WEEKDAYS = [
-            (u"Lun", u"Lundi"),
-            (u"Mar", u"Mardi"),
-            (u"Mer", u"Mercredi"),
-            (u"Jeu", u"Jeudi"),
-            (u"Ven", u"Vendredi"),
-            (u"Sam", u"Samedi"),
-            (u"Dim", u"Dimanche"),
+            ("Lun", "Lundi"),
+            ("Mar", "Mardi"),
+            ("Mer", "Mercredi"),
+            ("Jeu", "Jeudi"),
+            ("Ven", "Vendredi"),
+            ("Sam", "Samedi"),
+            ("Dim", "Dimanche"),
         ]
 
     def temporal(
-        stra, strb, granularity=u"days", parserinfo=FrenchParserInfo, dayfirst=True, yearfirst=False
+        stra, strb, granularity="days", parserinfo=FrenchParserInfo, dayfirst=True, yearfirst=False
     ):
         """ Return the distance between two strings (read as dates).
 
@@ -510,8 +524,8 @@ class BaseProcessing(object):
         The values are sorted as row 1, row2, ...
         """
         values = []
-        for i in xrange(len(dataset)):
-            for j in xrange(i + 1, len(dataset)):
+        for i in range(len(dataset)):
+            for j in range(i + 1, len(dataset)):
                 d = 1
                 if dataset[i] and dataset[j]:
                     d = self.distance(dataset[i], dataset[j])
@@ -640,7 +654,7 @@ if DATEUTIL_ENABLED:
             self,
             ref_attr_index=None,
             target_attr_index=None,
-            granularity=u"days",
+            granularity="days",
             parserinfo=FrenchParserInfo,
             dayfirst=True,
             yearfirst=False,
