@@ -20,169 +20,167 @@ from string import punctuation
 from unicodedata import normalize as _uninormalize
 from functools import partial
 
-from six import text_type, string_types
-
 FRENCH_STOPWORDS = set(
     [
-        u"alors",
-        u"au",
-        u"aux",
-        u"aucuns",
-        u"aussi",
-        u"autre",
-        u"avant",
-        u"avec",
-        u"avoir",
-        u"bon",
-        u"car",
-        u"ce",
-        u"cela",
-        u"ces",
-        u"ceux",
-        u"chaque",
-        u"ci",
-        u"comme",
-        u"comment",
-        u"dans",
-        u"de",
-        u"des",
-        u"du",
-        u"dedans",
-        u"dehors",
-        u"depuis",
-        u"deux",
-        u"devrait",
-        u"doit",
-        u"donc",
-        u"dos",
-        u"droite",
-        u"début",
-        u"elle",
-        u"elles",
-        u"en",
-        u"encore",
-        u"essai",
-        u"est",
-        u"et",
-        u"eu",
-        u"eux",
-        u"fait",
-        u"faites",
-        u"fois",
-        u"font",
-        u"force",
-        u"haut",
-        u"hors",
-        u"ici",
-        u"il",
-        u"ils",
-        u"je",
-        u"juste",
-        u"la",
-        u"le",
-        u"les",
-        u"leur",
-        u"lui",
-        u"là",
-        u"ma",
-        u"maintenant",
-        u"mais",
-        u"me",
-        u"mes",
-        u"moi",
-        u"moins",
-        u"mon",
-        u"mot",
-        u"même",
-        u"ne",
-        u"ni",
-        u"nommés",
-        u"nos",
-        u"notre",
-        u"nous",
-        u"nouveaux",
-        u"on",
-        u"ou",
-        u"où",
-        u"par",
-        u"parce",
-        u"parole",
-        u"pas",
-        u"personnes",
-        u"peut",
-        u"peu",
-        u"pièce",
-        u"plupart",
-        u"pour",
-        u"pourquoi",
-        u"quand",
-        u"que",
-        u"quel",
-        u"quelle",
-        u"quelles",
-        u"quels",
-        u"qui",
-        u"sa",
-        u"sans",
-        u"se",
-        u"ses",
-        u"seulement",
-        u"si",
-        u"sien",
-        u"son",
-        u"sont",
-        u"sous",
-        u"soyez",
-        u"sujet",
-        u"sur",
-        u"ta",
-        u"tandis",
-        u"tellement",
-        u"te",
-        u"tels",
-        u"tes",
-        u"toi",
-        u"ton",
-        u"tous",
-        u"tout",
-        u"trop",
-        u"très",
-        u"tu",
-        u"un",
-        u"une",
-        u"valeur",
-        u"voie",
-        u"voient",
-        u"vont",
-        u"vos",
-        u"votre",
-        u"vous",
-        u"vu",
-        u"ça",
-        u"étaient",
-        u"état",
-        u"étions",
-        u"été",
-        u"être",
+        "alors",
+        "au",
+        "aux",
+        "aucuns",
+        "aussi",
+        "autre",
+        "avant",
+        "avec",
+        "avoir",
+        "bon",
+        "car",
+        "ce",
+        "cela",
+        "ces",
+        "ceux",
+        "chaque",
+        "ci",
+        "comme",
+        "comment",
+        "dans",
+        "de",
+        "des",
+        "du",
+        "dedans",
+        "dehors",
+        "depuis",
+        "deux",
+        "devrait",
+        "doit",
+        "donc",
+        "dos",
+        "droite",
+        "début",
+        "elle",
+        "elles",
+        "en",
+        "encore",
+        "essai",
+        "est",
+        "et",
+        "eu",
+        "eux",
+        "fait",
+        "faites",
+        "fois",
+        "font",
+        "force",
+        "haut",
+        "hors",
+        "ici",
+        "il",
+        "ils",
+        "je",
+        "juste",
+        "la",
+        "le",
+        "les",
+        "leur",
+        "lui",
+        "là",
+        "ma",
+        "maintenant",
+        "mais",
+        "me",
+        "mes",
+        "moi",
+        "moins",
+        "mon",
+        "mot",
+        "même",
+        "ne",
+        "ni",
+        "nommés",
+        "nos",
+        "notre",
+        "nous",
+        "nouveaux",
+        "on",
+        "ou",
+        "où",
+        "par",
+        "parce",
+        "parole",
+        "pas",
+        "personnes",
+        "peut",
+        "peu",
+        "pièce",
+        "plupart",
+        "pour",
+        "pourquoi",
+        "quand",
+        "que",
+        "quel",
+        "quelle",
+        "quelles",
+        "quels",
+        "qui",
+        "sa",
+        "sans",
+        "se",
+        "ses",
+        "seulement",
+        "si",
+        "sien",
+        "son",
+        "sont",
+        "sous",
+        "soyez",
+        "sujet",
+        "sur",
+        "ta",
+        "tandis",
+        "tellement",
+        "te",
+        "tels",
+        "tes",
+        "toi",
+        "ton",
+        "tous",
+        "tout",
+        "trop",
+        "très",
+        "tu",
+        "un",
+        "une",
+        "valeur",
+        "voie",
+        "voient",
+        "vont",
+        "vos",
+        "votre",
+        "vous",
+        "vu",
+        "ça",
+        "étaient",
+        "état",
+        "étions",
+        "été",
+        "être",
     ]
 )
 
 MANUAL_UNICODE_MAP = {
-    u"\xa1": u"!",  # INVERTED EXCLAMATION MARK
-    u"\u0142": u"l",  # LATIN SMALL LETTER L WITH STROKE
-    u"\u2044": u"/",  # FRACTION SLASH
-    u"\xc6": u"AE",  # LATIN CAPITAL LETTER AE
-    u"\xa9": u"(c)",  # COPYRIGHT SIGN
-    u"\xab": u'"',  # LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
-    u"\xe6": u"ae",  # LATIN SMALL LETTER AE
-    u"\xae": u"(r)",  # REGISTERED SIGN
-    u"\u0153": u"oe",  # LATIN SMALL LIGATURE OE
-    u"\u0152": u"OE",  # LATIN CAPITAL LIGATURE OE
-    u"\xd8": u"O",  # LATIN CAPITAL LETTER O WITH STROKE
-    u"\xf8": u"o",  # LATIN SMALL LETTER O WITH STROKE
-    u"\xbb": u'"',  # RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
-    u"\xdf": u"ss",  # LATIN SMALL LETTER SHARP S
-    u"\u2019": u"'",  # RIGHT SINGLE QUOTATION MARK
+    "\xa1": "!",  # INVERTED EXCLAMATION MARK
+    "\u0142": "l",  # LATIN SMALL LETTER L WITH STROKE
+    "\u2044": "/",  # FRACTION SLASH
+    "\xc6": "AE",  # LATIN CAPITAL LETTER AE
+    "\xa9": "(c)",  # COPYRIGHT SIGN
+    "\xab": '"',  # LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
+    "\xe6": "ae",  # LATIN SMALL LETTER AE
+    "\xae": "(r)",  # REGISTERED SIGN
+    "\u0153": "oe",  # LATIN SMALL LIGATURE OE
+    "\u0152": "OE",  # LATIN CAPITAL LIGATURE OE
+    "\xd8": "O",  # LATIN CAPITAL LETTER O WITH STROKE
+    "\xf8": "o",  # LATIN SMALL LETTER O WITH STROKE
+    "\xbb": '"',  # RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
+    "\xdf": "ss",  # LATIN SMALL LETTER SHARP S
+    "\u2019": "'",  # RIGHT SINGLE QUOTATION MARK
 }
 
 
@@ -208,7 +206,7 @@ def unormalize(ustring, substitute=None):
         try:
             replacement = MANUAL_UNICODE_MAP[letter]
         except KeyError:
-            if isinstance(letter, text_type):
+            if isinstance(letter, str):
                 replacement = _uninormalize("NFKD", letter)[0]
             else:
                 replacement = letter
@@ -217,7 +215,7 @@ def unormalize(ustring, substitute=None):
                     raise ValueError("can't deal with non-ascii based characters")
                 replacement = substitute
         res.append(replacement)
-    return u"".join(res)
+    return "".join(res)
 
 
 def lunormalize(sentence, substitute=None):
@@ -232,7 +230,7 @@ def simplify(sentence, lemmas=None, remove_stopwords=True, stopwords=FRENCH_STOP
         2) Set the sentence to lower case
         3) Remove punctuation
     """
-    if not isinstance(sentence, string_types):
+    if not isinstance(sentence, str):
         return sentence
 
     if lemmas:
@@ -281,7 +279,7 @@ def lemmatized(sentence, lemmas, tokenizer=None):
             tokenized_sentformated[-1] += w
         elif w not in punctuation:
             tokenized_sentformated.append(w)
-    return u" ".join([lemmatized_word(w, lemmas) for w in tokenized_sentformated])
+    return " ".join([lemmatized_word(w, lemmas) for w in tokenized_sentformated])
 
 
 def lemmatized_word(word, lemmas):
